@@ -297,10 +297,9 @@ async def connection_create_snowflake(
             )
             assert isinstance(connection_name, str)
 
-            if no_validate is False:
-                if await client.get_connector(connection_name, "snowflake") is not None:
-                    click.echo(FeedbackManager.info_connection_already_exists(name=connection_name))
-                    connection_name = None
+            if no_validate is False and await client.get_connector(connection_name, "snowflake") is not None:
+                click.echo(FeedbackManager.info_connection_already_exists(name=connection_name))
+                connection_name = None
     assert isinstance(connection_name, str)
 
     show_instructions: bool = not is_ci_environment()
